@@ -22,8 +22,8 @@ import org.apache.skywalking.oap.server.library.module.ModuleDefine;
 import org.apache.skywalking.oap.server.library.module.ModuleProvider;
 import org.apache.skywalking.oap.server.library.module.ModuleStartException;
 import org.apache.skywalking.oap.server.library.module.ServiceNotProvidedException;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.powermock.reflect.Whitebox;
 
 public class UninstrumentedGatewaysConfigTest {
@@ -33,7 +33,7 @@ public class UninstrumentedGatewaysConfigTest {
             = new UninstrumentedGatewaysConfig(new MockProvider());
         UninstrumentedGatewaysConfig.GatewayInfos gatewayInfos
             = Whitebox.invokeMethod(uninstrumentedGatewaysConfig, "parseGatewaysFromFile", "gateways.yml");
-        Assert.assertEquals(1, gatewayInfos.getGateways().size());
+        Assertions.assertEquals(1, gatewayInfos.getGateways().size());
     }
 
     private static class MockProvider extends ModuleProvider {
