@@ -120,7 +120,7 @@ public class MetricConvert {
     }
 
     private void handleInitExp(String exp) {
-        Expression e = DSL.parse(exp);
+        Expression e = DSL.parse(null, exp);
         final Result result = e.run(ImmutableMap.of());
         if (!result.isSuccess() && result.isThrowable()) {
             throw new ExpressionParsingException(
