@@ -22,5 +22,5 @@ package org.apache.skywalking.oap.meter.analyzer.dsl;
  * DownsamplingType indicates the downsampling type of meter function
  */
 public enum DownsamplingType {
-    AVG, SUM, LATEST, SUM_PER_MIN
+    AVG, SUM, LATEST, SUM_PER_MIN, MAX, MIN
 }
