@@ -31,10 +31,6 @@ import java.util.List;
 @NoArgsConstructor
 public class Rule implements MetricRuleConfig {
     private String name;
-    private String fetcherInterval;
-    private String fetcherTimeout;
-    private String metricsPath;
-    private StaticConfig staticConfig;
     private String metricPrefix;
     private String expSuffix;
     private String expPrefix;
