@@ -453,7 +453,7 @@ public class ArithmeticTest {
                      String expression,
                      Result want,
                      boolean isThrow) {
-        Expression e = DSL.parse(expression);
+        Expression e = DSL.parse(name, expression);
         Result r = null;
         try {
             r = e.run(input);
