@@ -58,6 +58,7 @@ import org.apache.skywalking.oap.server.core.source.oal.rt.metrics.builder.Metri
 import org.apache.skywalking.oap.server.core.storage.StorageBuilderFactory;
 import org.apache.skywalking.oap.server.core.storage.annotation.BanyanDB;
 import org.apache.skywalking.oap.server.core.storage.annotation.Column;
+import org.apache.skywalking.oap.server.core.storage.annotation.ElasticSearch;
 import org.apache.skywalking.oap.server.library.util.StringUtil;
 
 import java.io.DataOutputStream;
@@ -205,6 +206,10 @@ public class OALClassGenerator {
                     Annotation banyanShardingKeyAnnotation = new Annotation(BanyanDB.SeriesID.class.getName(), constPool);
                     banyanShardingKeyAnnotation.addMemberValue("index", new IntegerMemberValue(constPool, 0));
                     annotationsAttribute.addAnnotation(banyanShardingKeyAnnotation);
+
+                    // Entity id field should enable doc values.
+                    final var enableDocValuesAnnotation = new Annotation(ElasticSearch.EnableDocValues.class.getName(), constPool);
+                    annotationsAttribute.addAnnotation(enableDocValuesAnnotation);
                 }
 
                 if (field.isGroupByCondInTopN()) {
@@ -428,6 +433,7 @@ public class OALClassGenerator {
             absent.setSourcePackage(oalDefine.getSourcePackage());
             absent.setSource(name);
             absent.setPackageName(name.toLowerCase());
+            absent.setSourceDecorator(metricsStmt.getSourceDecorator());
             return absent;
         });
         metricsStmt.setMetricsClassPackage(oalDefine.getDynamicMetricsClassPackage());
