@@ -51,7 +51,7 @@ public class RulesReaderTest {
     public void testReadRules() {
         RulesReader reader = new RulesReader(this.getClass()
                 .getClassLoader()
-                .getResourceAsStream("alarm-settings.yml"));
+                .getResourceAsStream("alarm-settings.yml"), null);
         Rules rules = reader.readRules();
 
         List<AlarmRule> ruleList = rules.getRules();
@@ -74,6 +74,10 @@ public class RulesReaderTest {
         WebhookSettings rulesWebhooks = rules.getWebhookSettingsMap().get(AlarmHooksType.webhook.name() + ".default");
         Assertions.assertEquals(2, rulesWebhooks.getUrls().size());
         Assertions.assertEquals("http://127.0.0.1/go-wechat/", rulesWebhooks.getUrls().get(1));
+        WebhookSettings rulesWebhooks2 = rules.getWebhookSettingsMap().get(AlarmHooksType.webhook.name() + ".custom1");
+        Assertions.assertEquals(2, rulesWebhooks2.getHeaders().size());
+        Assertions.assertEquals("Bearer bearer_token", rulesWebhooks2.getHeaders().get("Authorization"));
+        Assertions.assertEquals("arbitrary-additional-http-headers", rulesWebhooks2.getHeaders().get("x-company-header"));
 
         GRPCAlarmSetting grpcAlarmSetting = rules.getGrpcAlarmSettingMap().get(AlarmHooksType.gRPC.name() + ".default");
         assertNotNull(grpcAlarmSetting);
