@@ -19,14 +19,18 @@
 package org.apache.skywalking.oap.server.configuration.consul;
 
 import org.apache.skywalking.oap.server.library.module.ModuleStartException;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 public class ConsulConfigurationProviderTest {
 
-    @Test(expected = ModuleStartException.class)
-    public void shouldThrowWhenSettingsInvalid() throws ModuleStartException {
-        ConsulConfigurationProvider provider = new ConsulConfigurationProvider();
-        provider.newConfigCreator().onInitialized(new ConsulConfigurationCenterSettings());
-        provider.initConfigReader();
+    @Test
+    public void shouldThrowWhenSettingsInvalid() {
+        assertThrows(ModuleStartException.class, () -> {
+            ConsulConfigurationProvider provider = new ConsulConfigurationProvider();
+            provider.newConfigCreator().onInitialized(new ConsulConfigurationCenterSettings());
+            provider.initConfigReader();
+        });
     }
-}
\ No newline at end of file
+}
