@@ -21,18 +21,22 @@ package org.apache.skywalking.oap.server.core;
 import java.util.ArrayList;
 import java.util.List;
 import org.apache.skywalking.oap.server.core.analysis.meter.MeterSystem;
+import org.apache.skywalking.oap.server.core.cache.AsyncProfilerTaskCache;
 import org.apache.skywalking.oap.server.core.cache.NetworkAddressAliasCache;
 import org.apache.skywalking.oap.server.core.cache.ProfileTaskCache;
 import org.apache.skywalking.oap.server.core.command.CommandService;
 import org.apache.skywalking.oap.server.core.config.ConfigService;
 import org.apache.skywalking.oap.server.core.config.DownSamplingConfigService;
-import org.apache.skywalking.oap.server.core.config.IComponentLibraryCatalogService;
 import org.apache.skywalking.oap.server.core.config.HierarchyDefinitionService;
+import org.apache.skywalking.oap.server.core.config.IComponentLibraryCatalogService;
 import org.apache.skywalking.oap.server.core.config.NamingControl;
+import org.apache.skywalking.oap.server.core.config.group.EndpointNameGroupService;
 import org.apache.skywalking.oap.server.core.hierarchy.HierarchyService;
 import org.apache.skywalking.oap.server.core.management.ui.menu.UIMenuManagementService;
 import org.apache.skywalking.oap.server.core.management.ui.template.UITemplateManagementService;
 import org.apache.skywalking.oap.server.core.oal.rt.OALEngineLoaderService;
+import org.apache.skywalking.oap.server.core.profiling.asyncprofiler.AsyncProfilerMutationService;
+import org.apache.skywalking.oap.server.core.profiling.asyncprofiler.AsyncProfilerQueryService;
 import org.apache.skywalking.oap.server.core.profiling.continuous.ContinuousProfilingMutationService;
 import org.apache.skywalking.oap.server.core.profiling.continuous.ContinuousProfilingQueryService;
 import org.apache.skywalking.oap.server.core.profiling.ebpf.EBPFProfilingMutationService;
@@ -49,6 +53,7 @@ import org.apache.skywalking.oap.server.core.query.MetadataQueryService;
 import org.apache.skywalking.oap.server.core.query.MetricsMetadataQueryService;
 import org.apache.skywalking.oap.server.core.query.MetricsQueryService;
 import org.apache.skywalking.oap.server.core.query.RecordQueryService;
+import org.apache.skywalking.oap.server.core.query.TTLStatusQuery;
 import org.apache.skywalking.oap.server.core.query.TagAutoCompleteQueryService;
 import org.apache.skywalking.oap.server.core.query.TopNRecordsQueryService;
 import org.apache.skywalking.oap.server.core.query.TopologyQueryService;
@@ -93,16 +98,18 @@ public class CoreModule extends ModuleDefine {
 
         addServerInterface(classes);
         addReceiverInterface(classes);
-        addInsideService(classes);
+        addInternalServices(classes);
         addCacheService(classes);
         addQueryService(classes);
         addProfileService(classes);
         addOALService(classes);
         addManagementService(classes);
         addEBPFProfilingService(classes);
+        addAsyncProfilerService(classes);
 
         classes.add(CommandService.class);
         classes.add(HierarchyService.class);
+        classes.add(EndpointNameGroupService.class);
         return classes.toArray(new Class[]{});
     }
 
@@ -124,6 +131,12 @@ public class CoreModule extends ModuleDefine {
         classes.add(ProfileTaskCache.class);
     }
 
+    private void addAsyncProfilerService(List<Class> classes) {
+        classes.add(AsyncProfilerMutationService.class);
+        classes.add(AsyncProfilerQueryService.class);
+        classes.add(AsyncProfilerTaskCache.class);
+    }
+
     private void addOALService(List<Class> classes) {
         classes.add(OALEngineLoaderService.class);
     }
@@ -143,6 +156,7 @@ public class CoreModule extends ModuleDefine {
         classes.add(TagAutoCompleteQueryService.class);
         classes.add(RecordQueryService.class);
         classes.add(HierarchyQueryService.class);
+        classes.add(TTLStatusQuery.class);
     }
 
     private void addServerInterface(List<Class> classes) {
@@ -150,7 +164,7 @@ public class CoreModule extends ModuleDefine {
         classes.add(HTTPHandlerRegister.class);
     }
 
-    private void addInsideService(List<Class> classes) {
+    private void addInternalServices(List<Class> classes) {
         classes.add(ModelCreator.class);
         classes.add(IModelManager.class);
         classes.add(ModelManipulator.class);
