@@ -71,6 +71,15 @@ public class IDManager {
             return define.sourceId + Const.RELATION_ID_CONNECTOR + define.destId;
         }
 
+        /**
+         * @return encoded service hierarchy relation id
+         */
+        public static String buildServiceHierarchyRelationId(ServiceHierarchyRelationDefine define) {
+            return define.serviceId + Const.SERVICE_ID_CONNECTOR + define.serviceLayer.value() +
+                Const.RELATION_ID_CONNECTOR +
+                define.relatedServiceId + Const.SERVICE_ID_CONNECTOR + define.relatedServiceLayer.value();
+        }
+
         /**
          * @return service relation ID object decoded from {@link #buildRelationId(ServiceRelationDefine)} result
          */
@@ -100,6 +109,16 @@ public class IDManager {
             private final String sourceId;
             private final String destId;
         }
+
+        @RequiredArgsConstructor
+        @Getter
+        @EqualsAndHashCode
+        public static class ServiceHierarchyRelationDefine {
+            private final String serviceId;
+            private final Layer serviceLayer;
+            private final String relatedServiceId;
+            private final Layer relatedServiceLayer;
+        }
     }
 
     /**
@@ -140,6 +159,15 @@ public class IDManager {
             return define.sourceId + Const.RELATION_ID_CONNECTOR + define.destId;
         }
 
+        /**
+         * @return encoded instance hierarchy relation id
+         */
+        public static String buildInstanceHierarchyRelationId(InstanceHierarchyRelationDefine define) {
+            return define.instanceId + Const.SERVICE_ID_CONNECTOR + define.serviceLayer.value() +
+                Const.RELATION_ID_CONNECTOR +
+                define.relatedInstanceId + Const.SERVICE_ID_CONNECTOR + define.relatedServiceLayer.value();
+        }
+
         /**
          * @return service instance relation ID object decoded from {@link #buildRelationId(ServiceInstanceRelationDefine)}
          * result
@@ -175,6 +203,16 @@ public class IDManager {
              */
             private final String destId;
         }
+
+        @RequiredArgsConstructor
+        @Getter
+        @EqualsAndHashCode
+        public static class InstanceHierarchyRelationDefine {
+            private final String instanceId;
+            private final Layer serviceLayer;
+            private final String relatedInstanceId;
+            private final Layer relatedServiceLayer;
+        }
     }
 
     /**
