@@ -84,11 +84,14 @@ public class SegmentRecord extends Record {
     private String endpointId;
     @Setter
     @Getter
+    @ElasticSearch.EnableDocValues
     @Column(name = START_TIME)
     @BanyanDB.NoIndexing
     private long startTime;
     @Setter
     @Getter
+    @ElasticSearch.EnableDocValues
+    @BanyanDB.EnableSort
     @Column(name = LATENCY)
     private int latency;
     @Setter
