@@ -27,6 +27,7 @@ import org.apache.skywalking.oap.server.core.source.ScopeDeclaration;
 import org.apache.skywalking.oap.server.core.storage.StorageID;
 import org.apache.skywalking.oap.server.core.storage.annotation.BanyanDB;
 import org.apache.skywalking.oap.server.core.storage.annotation.Column;
+import org.apache.skywalking.oap.server.core.storage.annotation.ElasticSearch;
 import org.apache.skywalking.oap.server.core.storage.annotation.SQLDatabase;
 import org.apache.skywalking.oap.server.core.storage.type.Convert2Entity;
 import org.apache.skywalking.oap.server.core.storage.type.Convert2Storage;
@@ -59,9 +60,11 @@ public class ProfileThreadSnapshotRecord extends Record {
     @SQLDatabase.CompositeIndex(withColumns = {DUMP_TIME})
     @BanyanDB.SeriesID(index = 0)
     private String segmentId;
+    @ElasticSearch.EnableDocValues
     @Column(name = DUMP_TIME)
     @BanyanDB.NoIndexing
     private long dumpTime;
+    @ElasticSearch.EnableDocValues
     @Column(name = SEQUENCE)
     private int sequence;
     @Column(name = STACK_BINARY)
