@@ -21,11 +21,15 @@ package org.apache.skywalking.oap.server.core.query.type;
 import java.util.ArrayList;
 import java.util.List;
 import lombok.Getter;
+import lombok.Setter;
+import org.apache.skywalking.oap.server.core.query.type.debugging.DebuggingTrace;
 
 @Getter
 public class EndpointTopology {
     private final List<EndpointNode> nodes;
     private final List<Call> calls;
+    @Setter
+    private DebuggingTrace debuggingTrace;
 
     public EndpointTopology() {
         this.nodes = new ArrayList<>();
