@@ -22,14 +22,18 @@ import lombok.Getter;
 
 import java.util.ArrayList;
 import java.util.List;
+import lombok.Setter;
+import org.apache.skywalking.oap.server.core.query.type.debugging.DebuggingTrace;
 
 @Getter
 public class ProcessTopology {
     private final List<ProcessNode> nodes;
     private final List<Call> calls;
+    @Setter
+    private DebuggingTrace debuggingTrace;
 
     public ProcessTopology() {
         this.nodes = new ArrayList<>();
         this.calls = new ArrayList<>();
     }
-}
\ No newline at end of file
+}
