@@ -18,49 +18,37 @@
 
 package org.apache.skywalking.oap.server.core.storage.model;
 
-import java.util.List;
 import lombok.EqualsAndHashCode;
 import lombok.Getter;
+import lombok.RequiredArgsConstructor;
 import org.apache.skywalking.oap.server.core.analysis.DownSampling;
+import org.apache.skywalking.oap.server.core.analysis.metrics.Metrics;
+import org.apache.skywalking.oap.server.core.analysis.record.Record;
+
+import java.util.List;
 
 /**
  * The model definition of a logic entity.
  */
 @Getter
 @EqualsAndHashCode
+@RequiredArgsConstructor
 public class Model {
     private final String name;
     private final List<ModelColumn> columns;
     private final int scopeId;
     private final DownSampling downsampling;
-    private final boolean record;
     private final boolean superDataset;
-    private final boolean isTimeSeries;
     private final Class<?> streamClass;
     private final boolean timeRelativeID;
     private final SQLDatabaseModelExtension sqlDBModelExtension;
     private final BanyanDBModelExtension banyanDBModelExtension;
+    private final ElasticSearchModelExtension elasticSearchModelExtension;
 
-    public Model(final String name,
-                 final List<ModelColumn> columns,
-                 final int scopeId,
-                 final DownSampling downsampling,
-                 final boolean record,
-                 final boolean superDataset,
-                 final Class<?> streamClass,
-                 boolean timeRelativeID,
-                 final SQLDatabaseModelExtension sqlDBModelExtension,
-                 final BanyanDBModelExtension banyanDBModelExtension) {
-        this.name = name;
-        this.columns = columns;
-        this.scopeId = scopeId;
-        this.downsampling = downsampling;
-        this.isTimeSeries = !DownSampling.None.equals(downsampling);
-        this.record = record;
-        this.superDataset = superDataset;
-        this.streamClass = streamClass;
-        this.timeRelativeID = timeRelativeID;
-        this.sqlDBModelExtension = sqlDBModelExtension;
-        this.banyanDBModelExtension = banyanDBModelExtension;
-    }
+    @Getter(lazy = true)
+    private final boolean isMetric = Metrics.class.isAssignableFrom(getStreamClass());
+    @Getter(lazy = true)
+    private final boolean isRecord = Record.class.isAssignableFrom(getStreamClass());
+    @Getter(lazy = true)
+    private final boolean isTimeSeries = !DownSampling.None.equals(getDownsampling());
 }
