@@ -18,17 +18,15 @@
 
 package org.apache.skywalking.oap.server.core.storage.model;
 
-import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Optional;
 import lombok.AccessLevel;
 import lombok.EqualsAndHashCode;
 import lombok.Getter;
 import lombok.RequiredArgsConstructor;
-import lombok.Setter;
-import org.apache.skywalking.oap.server.core.storage.ShardingAlgorithm;
+
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 
 /**
  * @since 9.1.0
@@ -40,9 +38,6 @@ public class SQLDatabaseModelExtension {
     //exclude the columns from the main table
     private final List<ModelColumn> excludeColumns = new ArrayList<>(5);
 
-    @Setter
-    private Optional<Sharding> sharding = Optional.empty();
-
     public void appendAdditionalTable(String tableName, ModelColumn column) {
         additionalTables.computeIfAbsent(tableName, AdditionalTable::new)
                         .appendColumn(column);
@@ -52,10 +47,6 @@ public class SQLDatabaseModelExtension {
         excludeColumns.add(column);
     }
 
-    public boolean isShardingTable() {
-        return this.sharding.isPresent() && !this.sharding.get().getShardingAlgorithm().equals(ShardingAlgorithm.NO_SHARDING);
-    }
-
     @Getter
     @RequiredArgsConstructor(access = AccessLevel.PRIVATE)
     public static class AdditionalTable {
@@ -73,12 +64,4 @@ public class SQLDatabaseModelExtension {
             columns.add(column);
         }
     }
-
-    @Getter
-    @RequiredArgsConstructor
-    public static class Sharding {
-        private final ShardingAlgorithm shardingAlgorithm;
-        private final String dataSourceShardingColumn;
-        private final String tableShardingColumn;
-    }
 }
