@@ -20,12 +20,16 @@ package org.apache.skywalking.oap.server.health.checker.provider;
 
 import com.google.common.util.concurrent.AtomicDouble;
 import io.vavr.collection.Stream;
+
+import java.util.Arrays;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.stream.Collectors;
 import lombok.extern.slf4j.Slf4j;
+import org.apache.skywalking.oap.server.core.CoreModule;
+import org.apache.skywalking.oap.server.core.server.HTTPHandlerRegister;
 import org.apache.skywalking.oap.server.health.checker.module.HealthCheckerModule;
 import org.apache.skywalking.oap.server.library.module.ModuleDefine;
 import org.apache.skywalking.oap.server.library.module.ModuleProvider;
@@ -36,6 +40,8 @@ import org.apache.skywalking.oap.server.telemetry.TelemetryModule;
 import org.apache.skywalking.oap.server.telemetry.api.MetricsCollector;
 import org.apache.skywalking.oap.server.telemetry.api.MetricsCreator;
 
+import com.linecorp.armeria.common.HttpMethod;
+
 /**
  * HealthCheckerProvider fetches health check metrics from telemetry module, then calculates health score and generates
  * details explains the score. External service or users can query health status by HealthCheckerService.
@@ -48,6 +54,7 @@ public class HealthCheckerProvider extends ModuleProvider {
     private MetricsCollector collector;
     private MetricsCreator metricsCreator;
     private ScheduledExecutorService ses;
+    private HealthQueryService healthQueryService;
 
     @Override public String name() {
         return "default";
@@ -75,13 +82,19 @@ public class HealthCheckerProvider extends ModuleProvider {
     @Override public void prepare() throws ServiceNotProvidedException, ModuleStartException {
         score.set(-1);
         ses = Executors.newSingleThreadScheduledExecutor();
-        this.registerServiceImplementation(HealthQueryService.class, new HealthQueryService(score, details));
+        healthQueryService = new HealthQueryService(score, details);
+        this.registerServiceImplementation(HealthQueryService.class, healthQueryService);
     }
 
     @Override public void start() throws ServiceNotProvidedException, ModuleStartException {
         ModuleServiceHolder telemetry = getManager().find(TelemetryModule.NAME).provider();
         metricsCreator = telemetry.getService(MetricsCreator.class);
         collector = telemetry.getService(MetricsCollector.class);
+
+        final var service = getManager().find(CoreModule.NAME)
+                                        .provider()
+                                        .getService(HTTPHandlerRegister.class);
+        service.addHandler(new HealthCheckerHttpService(healthQueryService), Arrays.asList(HttpMethod.HEAD, HttpMethod.GET));
     }
 
     @Override public void notifyAfterCompleted() throws ServiceNotProvidedException, ModuleStartException {
