@@ -22,19 +22,20 @@ import java.util.List;
 import java.util.Properties;
 
 public interface IConsumer<T> {
-    void init(final Properties properties);
+    default void init(final Properties properties) {
+    }
 
     void consume(List<T> data);
 
     void onError(List<T> data, Throwable t);
 
-    void onExit();
+    default void onExit() {
+    }
 
     /**
      * Notify the implementation, if there is nothing fetched from the queue. This could be used as a timer to trigger
      * reaction if the queue has no element.
      */
     default void nothingToConsume() {
-        return;
     }
 }
