@@ -19,17 +19,11 @@
 package org.apache.skywalking.oap.server.library.datacarrier.consumer;
 
 import java.util.List;
-import java.util.Properties;
 import org.apache.skywalking.oap.server.library.datacarrier.SampleData;
 
 public class SampleConsumer implements IConsumer<SampleData> {
     public int i = 1;
 
-    @Override
-    public void init(final Properties properties) {
-
-    }
-
     @Override
     public void consume(List<SampleData> data) {
         for (SampleData one : data) {
@@ -42,9 +36,4 @@ public class SampleConsumer implements IConsumer<SampleData> {
     public void onError(List<SampleData> data, Throwable t) {
 
     }
-
-    @Override
-    public void onExit() {
-
-    }
 }
