@@ -91,7 +91,7 @@ public class MetadataQuery implements GraphQLQueryResolver {
 
     public List<Endpoint> searchEndpoint(final String keyword, final String serviceId,
                                          final int limit) throws IOException {
-        return getMetadataQueryService().findEndpoint(keyword, serviceId, limit);
+        return getMetadataQueryService().findEndpoint(keyword, serviceId, limit, null);
     }
 
     public List<Database> getAllDatabases(final Duration duration) throws IOException {
