@@ -167,15 +167,21 @@ public class TelemetryDataDispatcher {
 
         if (org.apache.skywalking.apm.network.common.v3.DetectPoint.server.equals(metrics.getDetectPoint())) {
             toTCPService(metrics, minuteTimeBucket);
-            toTCPServiceInstance(metrics, minuteTimeBucket);
-            toTCPServiceInstanceTraffic(metrics, minuteTimeBucket);
+            // Don't generate instance metrics, if no dest instance.
+            if (StringUtil.isNotEmpty(metrics.getDestServiceInstance())) {
+                toTCPServiceInstance(metrics, minuteTimeBucket);
+                toTCPServiceInstanceTraffic(metrics, minuteTimeBucket);
+            }
         }
 
         String sourceService = metrics.getSourceServiceName();
         // Don't generate relation, if no source.
         if (StringUtil.isNotEmpty(sourceService)) {
             toTCPServiceRelation(metrics, minuteTimeBucket);
-            toTCPServiceInstanceRelation(metrics, minuteTimeBucket);
+            // Don't generate instance relation, if no source instance.
+            if (StringUtil.isNotEmpty(metrics.getSourceServiceInstance())) {
+                toTCPServiceInstanceRelation(metrics, minuteTimeBucket);
+            }
         }
     }
 
@@ -184,16 +190,25 @@ public class TelemetryDataDispatcher {
 
         if (org.apache.skywalking.apm.network.common.v3.DetectPoint.server.equals(metrics.getDetectPoint())) {
             toService(metrics, minuteTimeBucket);
-            toServiceInstance(metrics, minuteTimeBucket);
-            toServiceInstanceTraffic(metrics, minuteTimeBucket);
-            toEndpoint(metrics, minuteTimeBucket);
+            // Don't generate instance metrics, if no dest instance.
+            if (StringUtil.isNotEmpty(metrics.getDestServiceInstance())) {
+                toServiceInstance(metrics, minuteTimeBucket);
+                toServiceInstanceTraffic(metrics, minuteTimeBucket);
+            }
+            // Don't generate endpoint metrics, if no endpoint.
+            if (StringUtil.isNotEmpty(metrics.getEndpoint())) {
+                toEndpoint(metrics, minuteTimeBucket);
+            }
         }
 
         String sourceService = metrics.getSourceServiceName();
         // Don't generate relation, if no source.
         if (StringUtil.isNotEmpty(sourceService)) {
             toServiceRelation(metrics, minuteTimeBucket);
-            toServiceInstanceRelation(metrics, minuteTimeBucket);
+            // Don't generate instance relation, if no source instance.
+            if (StringUtil.isNotEmpty(metrics.getSourceServiceInstance())) {
+                toServiceInstanceRelation(metrics, minuteTimeBucket);
+            }
         }
     }
 
@@ -224,6 +239,8 @@ public class TelemetryDataDispatcher {
         service.getSideCar().setInternalErrorCode(metrics.getInternalErrorCode());
         service.getSideCar().setInternalRequestLatencyNanos(metrics.getInternalRequestLatencyNanos());
         service.getSideCar().setInternalResponseLatencyNanos(metrics.getInternalResponseLatencyNanos());
+        service.setReceivedBytes(metrics.getReceivedBytes());
+        service.setSentBytes(metrics.getSentBytes());
 
         SOURCE_RECEIVER.receive(service);
     }
@@ -267,6 +284,8 @@ public class TelemetryDataDispatcher {
         serviceRelation.getSideCar().setInternalErrorCode(metrics.getInternalErrorCode());
         serviceRelation.getSideCar().setInternalRequestLatencyNanos(metrics.getInternalRequestLatencyNanos());
         serviceRelation.getSideCar().setInternalResponseLatencyNanos(metrics.getInternalResponseLatencyNanos());
+        serviceRelation.setReceivedBytes(metrics.getReceivedBytes());
+        serviceRelation.setSentBytes(metrics.getSentBytes());
 
         SOURCE_RECEIVER.receive(serviceRelation);
     }
@@ -298,6 +317,8 @@ public class TelemetryDataDispatcher {
         serviceInstance.getSideCar().setInternalErrorCode(metrics.getInternalErrorCode());
         serviceInstance.getSideCar().setInternalRequestLatencyNanos(metrics.getInternalRequestLatencyNanos());
         serviceInstance.getSideCar().setInternalResponseLatencyNanos(metrics.getInternalResponseLatencyNanos());
+        serviceInstance.setReceivedBytes(metrics.getReceivedBytes());
+        serviceInstance.setSentBytes(metrics.getSentBytes());
 
         SOURCE_RECEIVER.receive(serviceInstance);
     }
@@ -374,6 +395,8 @@ public class TelemetryDataDispatcher {
         serviceRelation.getSideCar().setInternalErrorCode(metrics.getInternalErrorCode());
         serviceRelation.getSideCar().setInternalRequestLatencyNanos(metrics.getInternalRequestLatencyNanos());
         serviceRelation.getSideCar().setInternalResponseLatencyNanos(metrics.getInternalResponseLatencyNanos());
+        serviceRelation.setReceivedBytes(metrics.getReceivedBytes());
+        serviceRelation.setSentBytes(metrics.getSentBytes());
 
         SOURCE_RECEIVER.receive(serviceRelation);
     }
