@@ -25,19 +25,28 @@ import org.apache.skywalking.oap.server.core.status.ServerStatusService;
 import org.apache.skywalking.oap.server.core.version.Version;
 import org.apache.skywalking.oap.server.library.module.ApplicationConfiguration;
 import org.apache.skywalking.oap.server.library.module.ModuleManager;
+import org.apache.skywalking.oap.server.library.module.TerminalFriendlyTable;
 import org.apache.skywalking.oap.server.starter.config.ApplicationConfigLoader;
 
+import static org.apache.skywalking.oap.server.library.module.TerminalFriendlyTable.Row;
+
 /**
  * Starter core. Load the core configuration file, and initialize the startup sequence through {@link ModuleManager}.
  */
 @Slf4j
 public class OAPServerBootstrap {
     public static void start() {
+        ModuleManager manager = new ModuleManager("Apache SkyWalking OAP");
+        final TerminalFriendlyTable bootingParameters = manager.getBootingParameters();
+
         String mode = System.getProperty("mode");
         RunningMode.setMode(mode);
 
-        ApplicationConfigLoader configLoader = new ApplicationConfigLoader();
-        ModuleManager manager = new ModuleManager();
+        ApplicationConfigLoader configLoader = new ApplicationConfigLoader(bootingParameters);
+
+        bootingParameters.addRow(new Row("Running Mode", mode));
+        bootingParameters.addRow(new Row("Version", Version.CURRENT.toString()));
+
         try {
             ApplicationConfiguration applicationConfiguration = configLoader.load();
             manager.init(applicationConfiguration);
@@ -45,9 +54,7 @@ public class OAPServerBootstrap {
             manager.find(CoreModule.NAME)
                    .provider()
                    .getService(ServerStatusService.class)
-                   .bootedNow(System.currentTimeMillis());
-
-            log.info("Version of OAP: {}", Version.CURRENT);
+                   .bootedNow(configLoader.getResolvedConfigurations(), System.currentTimeMillis());
 
             if (RunningMode.isInitMode()) {
                 log.info("OAP starts up in init mode successfully, exit now...");
@@ -56,6 +63,8 @@ public class OAPServerBootstrap {
         } catch (Throwable t) {
             log.error(t.getMessage(), t);
             System.exit(1);
+        } finally {
+            log.info(bootingParameters.toString());
         }
     }
 }
