@@ -65,12 +65,12 @@ public class BanyanDBAggregationQueryDAO extends AbstractBanyanDBDAO implements
         }
 
         // BanyanDB server-side TopN support for metrics pre-aggregation.
-        if (schema.getTopNSpec() != null) {
+        if (schema.getTopNSpec() != null && CollectionUtils.isEmpty(condition.getAttributes())) {
             // 1) no additional conditions
             // 2) additional conditions are all group by tags
             if (CollectionUtils.isEmpty(additionalConditions) ||
                     additionalConditions.stream().map(KeyValue::getKey).collect(Collectors.toSet())
-                            .equals(ImmutableSet.copyOf(schema.getTopNSpec().getGroupByTagNames()))) {
+                            .equals(ImmutableSet.copyOf(schema.getTopNSpec().getGroupByTagNamesList()))) {
                 return serverSideTopN(condition, schema, spec, timestampRange, additionalConditions);
             }
         }
@@ -82,9 +82,9 @@ public class BanyanDBAggregationQueryDAO extends AbstractBanyanDBDAO implements
                                         TimestampRange timestampRange, List<KeyValue> additionalConditions) throws IOException {
         TopNQueryResponse resp = null;
         if (condition.getOrder() == Order.DES) {
-            resp = topNQueryDebuggable(schema, timestampRange, condition.getTopN(), AbstractQuery.Sort.DESC, additionalConditions);
+            resp = topNQueryDebuggable(schema, timestampRange, condition.getTopN(), AbstractQuery.Sort.DESC, additionalConditions, condition.getAttributes());
         } else {
-            resp = topNQueryDebuggable(schema, timestampRange, condition.getTopN(), AbstractQuery.Sort.ASC, additionalConditions);
+            resp = topNQueryDebuggable(schema, timestampRange, condition.getTopN(), AbstractQuery.Sort.ASC, additionalConditions, condition.getAttributes());
         }
         if (resp.size() == 0) {
             return Collections.emptyList();
@@ -122,6 +122,15 @@ public class BanyanDBAggregationQueryDAO extends AbstractBanyanDBDAO implements
                                             additionalCondition.getValue()
                                     )));
                         }
+                        if (CollectionUtils.isNotEmpty(condition.getAttributes())) {
+                            condition.getAttributes().forEach(attr -> {
+                                if (attr.isEquals()) {
+                                    query.and(eq(attr.getKey(), attr.getValue()));
+                                } else {
+                                    query.and(ne(attr.getKey(), attr.getValue()));
+                                }
+                            });
+                        }
                     }
                 });
 
