@@ -18,43 +18,23 @@
 
 package org.apache.skywalking.oap.server.storage.plugin.banyandb;
 
-import com.fasterxml.jackson.core.type.TypeReference;
-import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.gson.JsonObject;
-import io.grpc.Status;
-
-import java.io.IOException;
-import java.lang.reflect.ParameterizedType;
-import java.util.ArrayList;
-import java.util.Comparator;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Objects;
-import java.util.Optional;
-import java.util.Set;
-import java.util.function.Function;
-import java.util.stream.Collectors;
-import javax.annotation.Nonnull;
-import javax.annotation.Nullable;
-
 import lombok.Builder;
 import lombok.Data;
 import lombok.EqualsAndHashCode;
 import lombok.Getter;
-import lombok.NoArgsConstructor;
 import lombok.RequiredArgsConstructor;
-import lombok.Setter;
 import lombok.Singular;
 import lombok.ToString;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.skywalking.banyandb.common.v1.BanyandbCommon;
-import org.apache.skywalking.banyandb.common.v1.BanyandbCommon.Group;
 import org.apache.skywalking.banyandb.common.v1.BanyandbCommon.Metadata;
-import org.apache.skywalking.banyandb.common.v1.BanyandbCommon.IntervalRule;
-import org.apache.skywalking.banyandb.common.v1.BanyandbCommon.Catalog;
-import org.apache.skywalking.banyandb.common.v1.BanyandbCommon.ResourceOpts;
 import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase;
+import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.Property;
+import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.CompressionMethod;
+import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.EncodingMethod;
+import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.FieldSpec;
+import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.FieldType;
 import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.IndexRule;
 import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.Measure;
 import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.Stream;
@@ -62,21 +42,13 @@ import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.TagFamilySpec
 import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.TagSpec;
 import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.TagType;
 import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.TopNAggregation;
-import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.FieldSpec;
-import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.FieldType;
-import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.CompressionMethod;
-import org.apache.skywalking.banyandb.database.v1.BanyandbDatabase.EncodingMethod;
 import org.apache.skywalking.banyandb.model.v1.BanyandbModel;
-import org.apache.skywalking.banyandb.v1.client.BanyanDBClient;
-import org.apache.skywalking.banyandb.v1.client.grpc.exception.BanyanDBException;
 import org.apache.skywalking.banyandb.v1.client.metadata.Duration;
-import org.apache.skywalking.banyandb.v1.client.metadata.MetadataCache;
-import org.apache.skywalking.banyandb.v1.client.metadata.ResourceExist;
 import org.apache.skywalking.oap.server.core.analysis.DownSampling;
 import org.apache.skywalking.oap.server.core.analysis.metrics.IntList;
 import org.apache.skywalking.oap.server.core.analysis.metrics.Metrics;
 import org.apache.skywalking.oap.server.core.analysis.record.Record;
-import org.apache.skywalking.oap.server.core.config.ConfigService;
+import org.apache.skywalking.oap.server.core.config.DownSamplingConfigService;
 import org.apache.skywalking.oap.server.core.query.enumeration.Step;
 import org.apache.skywalking.oap.server.core.storage.StorageException;
 import org.apache.skywalking.oap.server.core.storage.annotation.BanyanDB;
@@ -88,30 +60,42 @@ import org.apache.skywalking.oap.server.core.storage.type.StorageDataComplexObje
 import org.apache.skywalking.oap.server.library.util.CollectionUtils;
 import org.apache.skywalking.oap.server.library.util.StringUtil;
 
+import javax.annotation.Nonnull;
+import javax.annotation.Nullable;
+import java.lang.reflect.ParameterizedType;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Comparator;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Objects;
+import java.util.Optional;
+import java.util.Set;
+import java.util.function.Function;
+import java.util.stream.Collectors;
+
 @Slf4j
 public enum MetadataRegistry {
     INSTANCE;
 
-    private static final ObjectMapper MAPPER = new ObjectMapper();
     private final Map<String, Schema> registry = new HashMap<>();
 
-    private Map<String, GroupSetting> specificGroupSettings = new HashMap<>();
-
-    public StreamModel registerStreamModel(Model model, BanyanDBStorageConfig config, ConfigService configService) {
+    public StreamModel registerStreamModel(Model model, BanyanDBStorageConfig config, DownSamplingConfigService configService) {
         final SchemaMetadata schemaMetadata = parseMetadata(model, config, configService);
         Schema.SchemaBuilder schemaBuilder = Schema.builder().metadata(schemaMetadata);
         Map<String, ModelColumn> modelColumnMap = model.getColumns().stream()
                 .collect(Collectors.toMap(modelColumn -> modelColumn.getColumnName().getStorageName(), Function.identity()));
-        // parse and set sharding keys
-        List<String> shardingColumns = parseEntityNames(modelColumnMap);
-        if (shardingColumns.isEmpty()) {
-            throw new IllegalStateException("sharding keys of model[stream." + model.getName() + "] must not be empty");
+        // parse and set seriesIDs
+        List<String> seriesIDColumns = parseEntityNames(modelColumnMap);
+        if (seriesIDColumns.isEmpty()) {
+            throw new IllegalStateException("seriesID of model[stream." + model.getName() + "] must not be empty");
         }
         // parse tag metadata
         // this can be used to build both
         // 1) a list of TagFamilySpec,
         // 2) a list of IndexRule,
-        List<TagMetadata> tags = parseTagMetadata(model, schemaBuilder, shardingColumns, schemaMetadata.group);
+        List<TagMetadata> tags = parseTagMetadata(model, schemaBuilder, seriesIDColumns, schemaMetadata.group);
         List<TagFamilySpec> tagFamilySpecs = schemaMetadata.extractTagFamilySpec(tags, false);
         // iterate over tagFamilySpecs to save tag names
         for (final TagFamilySpec tagFamilySpec : tagFamilySpecs) {
@@ -132,29 +116,29 @@ public enum MetadataRegistry {
 
         final Stream.Builder builder = Stream.newBuilder();
         builder.setMetadata(BanyandbCommon.Metadata.newBuilder().setGroup(schemaMetadata.getGroup())
-                                .setName(schemaMetadata.name()));
-        builder.setEntity(BanyandbDatabase.Entity.newBuilder().addAllTagNames(shardingColumns));
+                .setName(schemaMetadata.name()));
+        builder.setEntity(BanyandbDatabase.Entity.newBuilder().addAllTagNames(seriesIDColumns));
         builder.addAllTagFamilies(tagFamilySpecs);
 
         registry.put(schemaMetadata.name(), schemaBuilder.build());
         return new StreamModel(builder.build(), indexRules);
     }
 
-    public MeasureModel registerMeasureModel(Model model, BanyanDBStorageConfig config, ConfigService configService) throws StorageException {
+    public MeasureModel registerMeasureModel(Model model, BanyanDBStorageConfig config, DownSamplingConfigService configService) throws StorageException {
         final SchemaMetadata schemaMetadata = parseMetadata(model, config, configService);
         Schema.SchemaBuilder schemaBuilder = Schema.builder().metadata(schemaMetadata);
         Map<String, ModelColumn> modelColumnMap = model.getColumns().stream()
                 .collect(Collectors.toMap(modelColumn -> modelColumn.getColumnName().getStorageName(), Function.identity()));
-        // parse and set sharding keys
-        List<String> shardingColumns = parseEntityNames(modelColumnMap);
-        if (shardingColumns.isEmpty()) {
+        // parse and set seriesIDs
+        List<String> seriesIDColumns = parseEntityNames(modelColumnMap);
+        if (seriesIDColumns.isEmpty()) {
             throw new StorageException("model " + model.getName() + " doesn't contain series id");
         }
         // parse tag metadata
         // this can be used to build both
         // 1) a list of TagFamilySpec,
         // 2) a list of IndexRule,
-        MeasureMetadata tagsAndFields = parseTagAndFieldMetadata(model, schemaBuilder, shardingColumns, schemaMetadata.group);
+        MeasureMetadata tagsAndFields = parseTagAndFieldMetadata(model, schemaBuilder, seriesIDColumns, schemaMetadata.group);
         List<TagFamilySpec> tagFamilySpecs = schemaMetadata.extractTagFamilySpec(tagsAndFields.tags, model.getBanyanDBModelExtension().isStoreIDTag());
         // iterate over tagFamilySpecs to save tag names
         for (final TagFamilySpec tagFamilySpec : tagFamilySpecs) {
@@ -168,28 +152,47 @@ public enum MetadataRegistry {
                 .collect(Collectors.toList());
 
         if (model.getBanyanDBModelExtension().isStoreIDTag()) {
-            indexRules.add(indexRule(schemaMetadata.group, BanyanDBConverter.ID, null));
+            indexRules.add(indexRule(schemaMetadata.group, BanyanDBConverter.ID, false, null));
         }
 
         final Measure.Builder builder = Measure.newBuilder();
         builder.setMetadata(BanyandbCommon.Metadata.newBuilder().setGroup(schemaMetadata.getGroup())
-                                .setName(schemaMetadata.name()));
+                .setName(schemaMetadata.name()));
         builder.setInterval(downSamplingDuration(model.getDownsampling()).format());
-        builder.setEntity(BanyandbDatabase.Entity.newBuilder().addAllTagNames(shardingColumns));
+        builder.setEntity(BanyandbDatabase.Entity.newBuilder().addAllTagNames(seriesIDColumns));
         builder.addAllTagFamilies(tagFamilySpecs);
+        if (model.getBanyanDBModelExtension().isIndexMode()) {
+            builder.setIndexMode(true);
+            if (!tagsAndFields.fields.isEmpty()) {
+                throw new StorageException("index mode is enabled, but fields are defined");
+            }
+        }
         // parse and set field
         for (BanyandbDatabase.FieldSpec field : tagsAndFields.fields) {
             builder.addFields(field);
             schemaBuilder.field(field.getName());
         }
         // parse TopN
-        schemaBuilder.topNSpec(parseTopNSpec(model, schemaMetadata.name()));
+        schemaBuilder.topNSpec(parseTopNSpec(model, schemaMetadata.group, schemaMetadata.name()));
 
         registry.put(schemaMetadata.name(), schemaBuilder.build());
         return new MeasureModel(builder.build(), indexRules);
     }
 
-    private TopNSpec parseTopNSpec(final Model model, final String measureName)
+    public PropertyModel registerPropertyModel(Model model, BanyanDBStorageConfig config) {
+        final SchemaMetadata schemaMetadata = parseMetadata(model, config, null);
+        Schema.SchemaBuilder schemaBuilder = Schema.builder().metadata(schemaMetadata);
+        List<TagMetadata> tags = parseTagMetadata(model, schemaBuilder, Collections.emptyList(), schemaMetadata.group);
+        final Property.Builder builder = Property.newBuilder();
+        builder.setMetadata(BanyandbCommon.Metadata.newBuilder().setGroup(schemaMetadata.getGroup())
+                .setName(schemaMetadata.name()));
+        for (TagMetadata tag : tags) {
+            builder.addTags(tag.getTagSpec());
+        }
+        return new PropertyModel(builder.build());
+    }
+
+    private TopNAggregation parseTopNSpec(final Model model, final String group, final String measureName)
             throws StorageException {
         if (model.getBanyanDBModelExtension().getTopN() == null) {
             return null;
@@ -204,14 +207,16 @@ public enum MetadataRegistry {
         if (CollectionUtils.isEmpty(model.getBanyanDBModelExtension().getTopN().getGroupByTagNames())) {
             throw new StorageException("invalid groupBy tags: " + model.getBanyanDBModelExtension().getTopN().getGroupByTagNames());
         }
-        return TopNSpec.builder()
-                .name(measureName + "_topn")
-                .lruSize(model.getBanyanDBModelExtension().getTopN().getLruSize())
-                .countersNumber(model.getBanyanDBModelExtension().getTopN().getCountersNumber())
-                .fieldName(valueColumnOpt.get().getValueCName())
-                .groupByTagNames(model.getBanyanDBModelExtension().getTopN().getGroupByTagNames())
-                .sort(BanyandbModel.Sort.SORT_UNSPECIFIED) // include both TopN and BottomN
-                .build();
+        return TopNAggregation.newBuilder()
+                              .setMetadata(
+                                  Metadata.newBuilder().setGroup(group).setName(Schema.formatTopNName(measureName)))
+                              .setSourceMeasure(Metadata.newBuilder().setGroup(group).setName(measureName))
+                              .setFieldValueSort(BanyandbModel.Sort.SORT_UNSPECIFIED) // include both TopN and BottomN
+                              .setFieldName(valueColumnOpt.get().getValueCName())
+                              .addAllGroupByTagNames(model.getBanyanDBModelExtension().getTopN().getGroupByTagNames())
+                              .setCountersNumber(model.getBanyanDBModelExtension().getTopN().getCountersNumber())
+                              .setLruSize(model.getBanyanDBModelExtension().getTopN().getLruSize())
+                              .build();
     }
 
     public Schema findMetadata(final Model model) {
@@ -261,27 +266,27 @@ public enum MetadataRegistry {
         String colName = modelColumn.getColumnName().getStorageName();
         if (String.class.equals(modelColumn.getType())) {
             return FieldSpec.newBuilder().setName(colName)
-                            .setFieldType(FieldType.FIELD_TYPE_STRING)
-                            .setCompressionMethod(CompressionMethod.COMPRESSION_METHOD_ZSTD)
-                            .build();
+                    .setFieldType(FieldType.FIELD_TYPE_STRING)
+                    .setCompressionMethod(CompressionMethod.COMPRESSION_METHOD_ZSTD)
+                    .build();
         } else if (long.class.equals(modelColumn.getType()) || int.class.equals(modelColumn.getType())) {
             return FieldSpec.newBuilder().setName(colName)
-                            .setFieldType(FieldType.FIELD_TYPE_INT)
-                            .setCompressionMethod(CompressionMethod.COMPRESSION_METHOD_ZSTD)
-                            .setEncodingMethod(EncodingMethod.ENCODING_METHOD_GORILLA)
-                            .build();
+                    .setFieldType(FieldType.FIELD_TYPE_INT)
+                    .setCompressionMethod(CompressionMethod.COMPRESSION_METHOD_ZSTD)
+                    .setEncodingMethod(EncodingMethod.ENCODING_METHOD_GORILLA)
+                    .build();
         } else if (StorageDataComplexObject.class.isAssignableFrom(modelColumn.getType()) || JsonObject.class.equals(modelColumn.getType())) {
             return FieldSpec.newBuilder().setName(colName)
-                            .setFieldType(FieldType.FIELD_TYPE_STRING)
-                            .setCompressionMethod(CompressionMethod.COMPRESSION_METHOD_ZSTD)
-                            .build();
+                    .setFieldType(FieldType.FIELD_TYPE_STRING)
+                    .setCompressionMethod(CompressionMethod.COMPRESSION_METHOD_ZSTD)
+                    .build();
         } else if (double.class.equals(modelColumn.getType())) {
             // TODO: natively support double/float in BanyanDB
             log.warn("Double is stored as binary");
             return FieldSpec.newBuilder().setName(colName)
-                            .setFieldType(FieldType.FIELD_TYPE_DATA_BINARY)
-                            .setCompressionMethod(CompressionMethod.COMPRESSION_METHOD_ZSTD)
-                            .build();
+                    .setFieldType(FieldType.FIELD_TYPE_DATA_BINARY)
+                    .setCompressionMethod(CompressionMethod.COMPRESSION_METHOD_ZSTD)
+                    .build();
         } else {
             throw new UnsupportedOperationException(modelColumn.getType().getSimpleName() + " is not supported for field");
         }
@@ -300,10 +305,12 @@ public enum MetadataRegistry {
         }
     }
 
-    IndexRule indexRule(String group, String tagName, BanyanDB.MatchQuery.AnalyzerType analyzer) {
+    IndexRule indexRule(String group, String tagName, boolean enableSort,  BanyanDB.MatchQuery.AnalyzerType analyzer) {
         IndexRule.Builder builder = IndexRule.newBuilder()
                                              .setMetadata(Metadata.newBuilder().setName(tagName).setGroup(group))
                                              .setType(IndexRule.Type.TYPE_INVERTED).addTags(tagName);
+        // *Notice*: here is a reverse logic, if enableSort is true, then setNoSort is false
+        builder.setNoSort(!enableSort);
         if (analyzer != null) {
             switch (analyzer) {
                 case KEYWORD:
@@ -326,20 +333,20 @@ public enum MetadataRegistry {
     }
 
     /**
-     * Parse sharding keys from the {@link Model}
+     * Parse SeriesID from the {@link Model}
      *
      * @param modelColumnMap the mapping between column storageName and {@link ModelColumn}
      * @return a list of column names in strict order
      */
     List<String> parseEntityNames(Map<String, ModelColumn> modelColumnMap) {
-        List<ModelColumn> shardingColumns = new ArrayList<>();
+        List<ModelColumn> seriesIDColumns = new ArrayList<>();
         for (final ModelColumn col : modelColumnMap.values()) {
-            if (col.getBanyanDBExtension().isShardingKey()) {
-                shardingColumns.add(col);
+            if (col.getBanyanDBExtension().isSeriesID()) {
+                seriesIDColumns.add(col);
             }
         }
-        return shardingColumns.stream()
-                .sorted(Comparator.comparingInt(col -> col.getBanyanDBExtension().getShardingKeyIdx()))
+        return seriesIDColumns.stream()
+                .sorted(Comparator.comparingInt(col -> col.getBanyanDBExtension().getSeriesIDIdx()))
                 .map(col -> col.getColumnName().getName())
                 .collect(Collectors.toList());
     }
@@ -351,7 +358,7 @@ public enum MetadataRegistry {
      *
      * @since 9.4.0 Skip {@link Record#TIME_BUCKET}
      */
-    List<TagMetadata> parseTagMetadata(Model model, Schema.SchemaBuilder builder, List<String> shardingColumns, String group) {
+    List<TagMetadata> parseTagMetadata(Model model, Schema.SchemaBuilder builder, List<String> seriesIDColumns, String group) {
         List<TagMetadata> tagMetadataList = new ArrayList<>();
         for (final ModelColumn col : model.getColumns()) {
             final String columnStorageName = col.getColumnName().getStorageName();
@@ -362,9 +369,12 @@ public enum MetadataRegistry {
             builder.spec(columnStorageName, new ColumnSpec(ColumnType.TAG, col.getType()));
             String colName = col.getColumnName().getStorageName();
             if (col.getBanyanDBExtension().shouldIndex()) {
-                if (!shardingColumns.contains(colName) || null != col.getBanyanDBExtension().getAnalyzer()) {
+                if (!seriesIDColumns.contains(colName) || null != col.getBanyanDBExtension().getAnalyzer()) {
                     tagMetadataList.add(new TagMetadata(
-                        indexRule(group, tagSpec.getName(), col.getBanyanDBExtension().getAnalyzer()), tagSpec));
+                        indexRule(
+                            group, tagSpec.getName(), col.getBanyanDBExtension().isEnableSort(),
+                            col.getBanyanDBExtension().getAnalyzer()
+                        ), tagSpec));
                 } else {
                     tagMetadataList.add(new TagMetadata(null, tagSpec));
                 }
@@ -391,7 +401,7 @@ public enum MetadataRegistry {
      *
      * @since 9.4.0 Skip {@link Metrics#TIME_BUCKET}
      */
-    MeasureMetadata parseTagAndFieldMetadata(Model model, Schema.SchemaBuilder builder, List<String> shardingColumns, String group) {
+    MeasureMetadata parseTagAndFieldMetadata(Model model, Schema.SchemaBuilder builder, List<String> seriesIDColumns, String group) {
         // skip metric
         MeasureMetadata.MeasureMetadataBuilder result = MeasureMetadata.builder();
         for (final ModelColumn col : model.getColumns()) {
@@ -409,9 +419,12 @@ public enum MetadataRegistry {
             String colName = col.getColumnName().getStorageName();
 
             if (col.getBanyanDBExtension().shouldIndex()) {
-                if (!shardingColumns.contains(colName) || null != col.getBanyanDBExtension().getAnalyzer()) {
+                if (!seriesIDColumns.contains(colName) || null != col.getBanyanDBExtension().getAnalyzer()) {
                     result.tag(new TagMetadata(
-                        indexRule(group, tagSpec.getName(), col.getBanyanDBExtension().getAnalyzer()), tagSpec));
+                        indexRule(
+                            group, tagSpec.getName(), col.getBanyanDBExtension().isEnableSort(),
+                            col.getBanyanDBExtension().getAnalyzer()
+                        ), tagSpec));
                 } else {
                     result.tag(new TagMetadata(null, tagSpec));
                 }
@@ -436,7 +449,7 @@ public enum MetadataRegistry {
         TagSpec.Builder tagSpec = TagSpec.newBuilder().setName(colName);
         if (String.class.equals(clazz) || StorageDataComplexObject.class.isAssignableFrom(clazz) || JsonObject.class.equals(clazz)) {
             tagSpec = tagSpec.setType(TagType.TAG_TYPE_STRING);
-        } else if (int.class.equals(clazz) || long.class.equals(clazz)) {
+        } else if (int.class.equals(clazz) || long.class.equals(clazz) || Integer.class.equals(clazz) || Long.class.equals(clazz)) {
             tagSpec = tagSpec.setType(TagType.TAG_TYPE_INT);
         } else if (byte[].class.equals(clazz)) {
             tagSpec = tagSpec.setType(TagType.TAG_TYPE_DATA_BINARY);
@@ -462,69 +475,62 @@ public enum MetadataRegistry {
         return tagSpec.build();
     }
 
-    public void initializeIntervals(String specificGroupSettingsStr) {
-        if (StringUtil.isBlank(specificGroupSettingsStr)) {
-            return;
+    public SchemaMetadata parseMetadata(Model model, BanyanDBStorageConfig config, DownSamplingConfigService configService) {
+        if (!model.isTimeSeries()) {
+            return new SchemaMetadata(BanyanDBStorageConfig.PROPERTY_GROUP_NAME, model.getName(), Kind.PROPERTY, DownSampling.None, config.getProperty().getShardNum(), 0, 0);
         }
-        try {
-            specificGroupSettings = MAPPER.readerFor(new TypeReference<Map<String, GroupSetting>>() {
-            }).readValue(specificGroupSettingsStr);
-        } catch (IOException ioEx) {
-            log.warn("fail to parse specificGroupSettings", ioEx);
-        }
-    }
-
-    public SchemaMetadata parseMetadata(Model model, BanyanDBStorageConfig config, ConfigService configService) {
-        int segmentIntervalDays = config.getSegmentIntervalDays();
-        if (model.isSuperDataset()) {
-            segmentIntervalDays = config.getSuperDatasetSegmentIntervalDays();
-        }
-        String group;
-        int metricShardNum = config.getMetricsShardsNumber();
         if (model.isRecord()) { // stream
-            group = "stream-default";
-            if (model.isSuperDataset()) {
-                // for superDataset, we should use separate group
-                group = "stream-" + model.getName();
-            }
-        } else if (model.getDownsampling() == DownSampling.Minute && model.isTimeRelativeID()) { // measure
-            group = "measure-minute";
-            // apply super dataset's settings to measure-minute
-            segmentIntervalDays = config.getSuperDatasetSegmentIntervalDays();
-            metricShardNum = metricShardNum * config.getSuperDatasetShardsFactor();
-        } else {
-            // Solution: 2 * TTL < T * (1 + 0.8)
-            // e.g. if TTL=7, T=8: a new block/segment will be created at 14.4 days,
-            // while the first block has been deleted at 2*TTL
-            final int intervalDays = Double.valueOf(Math.ceil(configService.getMetricsDataTTL() * 2.0 / 1.8)).intValue();
-            return new SchemaMetadata("measure-default", model.getName(), Kind.MEASURE,
-                    model.getDownsampling(),
-                    config.getMetricsShardsNumber(),
-                    intervalDays, // use 10-day/240-hour strategy
-                    configService.getMetricsDataTTL());
-        }
-
-        GroupSetting groupSetting = this.specificGroupSettings.get(group);
-        if (groupSetting != null) {
-            segmentIntervalDays = groupSetting.getSegmentIntervalDays();
-        }
-        if (model.isRecord()) {
-            return new SchemaMetadata(group,
+            return new SchemaMetadata(model.isSuperDataset() ? model.getName() : "normal",
                     model.getName(),
                     Kind.STREAM,
                     model.getDownsampling(),
-                    config.getRecordShardsNumber() *
-                            (model.isSuperDataset() ? config.getSuperDatasetShardsFactor() : 1),
-                    segmentIntervalDays,
-                    configService.getRecordDataTTL()
-            );
+                    model.isSuperDataset() ? config.getRecordsSuper().getShardNum() : config.getRecordsNormal().getShardNum(),
+                    model.isSuperDataset() ? config.getRecordsSuper().getSegmentInterval() : config.getRecordsNormal().getSegmentInterval(),
+                    model.isSuperDataset() ? config.getRecordsSuper().getTtl() : config.getRecordsNormal().getTtl());
+        }
+
+        if (model.getBanyanDBModelExtension().isIndexMode()) {
+            return new SchemaMetadata("index", model.getName(), Kind.MEASURE,
+                    model.getDownsampling(),
+                    config.getMetadata().getShardNum(),
+                    config.getMetadata().getSegmentInterval(),
+                    config.getMetadata().getTtl());
+        }
+
+        switch (model.getDownsampling()) {
+            case Minute:
+                return new SchemaMetadata(DownSampling.Minute.getName(),
+                        model.getName(),
+                        Kind.MEASURE,
+                        model.getDownsampling(),
+                        config.getMetricsMin().getShardNum(),
+                        config.getMetricsMin().getSegmentInterval(),
+                        config.getMetricsMin().getTtl());
+            case Hour:
+                if (!configService.shouldToHour()) {
+                    throw new UnsupportedOperationException("downsampling to hour is not supported");
+                }
+                return new SchemaMetadata(DownSampling.Hour.getName(),
+                        model.getName(),
+                        Kind.MEASURE,
+                        model.getDownsampling(),
+                        config.getMetricsHour().getShardNum(),
+                        config.getMetricsHour().getSegmentInterval(),
+                        config.getMetricsHour().getTtl());
+            case Day:
+                if (!configService.shouldToDay()) {
+                    throw new UnsupportedOperationException("downsampling to day is not supported");
+                }
+                return new SchemaMetadata(DownSampling.Day.getName(),
+                        model.getName(),
+                        Kind.MEASURE,
+                        model.getDownsampling(),
+                        config.getMetricsDay().getShardNum(),
+                        config.getMetricsDay().getSegmentInterval(),
+                        config.getMetricsDay().getTtl());
+            default:
+                throw new UnsupportedOperationException("unsupported downSampling interval:" + model.getDownsampling());
         }
-        // FIX: address issue #10104
-        return new SchemaMetadata(group, model.getName(), Kind.MEASURE,
-                model.getDownsampling(),
-                metricShardNum,
-                segmentIntervalDays,
-                configService.getMetricsDataTTL());
     }
 
     @RequiredArgsConstructor
@@ -559,36 +565,6 @@ public enum MetadataRegistry {
             return modelName + "_" + downSampling.getName();
         }
 
-        public Optional<Object> findRemoteSchema(BanyanDBClient client) throws BanyanDBException {
-            try {
-                switch (kind) {
-                    case STREAM:
-                        return Optional.ofNullable(client.findStream(this.group, this.name()));
-                    case MEASURE:
-                        return Optional.ofNullable(client.findMeasure(this.group, this.name()));
-                    default:
-                        throw new IllegalStateException("should not reach here");
-                }
-            } catch (BanyanDBException ex) {
-                if (ex.getStatus().equals(Status.Code.NOT_FOUND)) {
-                    return Optional.empty();
-                }
-
-                throw ex;
-            }
-        }
-
-        public MetadataCache.EntityMetadata updateRemoteSchema(BanyanDBClient client) throws BanyanDBException {
-            switch (kind) {
-                case STREAM:
-                    return client.updateStreamMetadataCacheFromSever(this.group, this.name());
-                case MEASURE:
-                    return client.updateMeasureMetadataCacheFromSever(this.group, this.name());
-                default:
-                    throw new IllegalStateException("should not reach here");
-            }
-        }
-
         private List<TagFamilySpec> extractTagFamilySpec(List<TagMetadata> tagMetadataList, boolean shouldAddID) {
             final String indexFamily = SchemaMetadata.this.indexFamily();
             final String nonIndexFamily = SchemaMetadata.this.nonIndexFamily();
@@ -609,65 +585,6 @@ public enum MetadataRegistry {
             return tagFamilySpecs;
         }
 
-        public boolean checkResourceExistence(BanyanDBClient client) throws BanyanDBException {
-            ResourceExist resourceExist;
-            Group.Builder gBuilder
-                = Group.newBuilder()
-                       .setMetadata(Metadata.newBuilder().setName(this.group))
-                       .setResourceOpts(ResourceOpts.newBuilder()
-                                                    .setShardNum(this.shard)
-                                                    .setSegmentInterval(
-                                                        IntervalRule.newBuilder()
-                                                                    .setUnit(
-                                                                        IntervalRule.Unit.UNIT_DAY)
-                                                                    .setNum(
-                                                                        this.segmentIntervalDays))
-                                                    .setTtl(
-                                                        IntervalRule.newBuilder()
-                                                                    .setUnit(
-                                                                        IntervalRule.Unit.UNIT_DAY)
-                                                                    .setNum(
-                                                                        this.ttlDays)));
-            switch (kind) {
-                case STREAM:
-                    resourceExist = client.existStream(this.group, this.name());
-                    if (!resourceExist.hasGroup()) {
-                        try {
-                            Group g = client.define(gBuilder.setCatalog(Catalog.CATALOG_STREAM).build());
-                            if (g != null) {
-                                log.info("group {} created", g.getMetadata().getName());
-                            }
-                        } catch (BanyanDBException ex) {
-                            if (ex.getStatus().equals(Status.Code.ALREADY_EXISTS)) {
-                                log.info("group {} already created by another OAP node", this.group);
-                            } else {
-                                throw ex;
-                            }
-                        }
-                    }
-                    return resourceExist.hasResource();
-                case MEASURE:
-                    resourceExist = client.existMeasure(this.group, this.name());
-                    try {
-                        if (!resourceExist.hasGroup()) {
-                            Group g = client.define(gBuilder.setCatalog(Catalog.CATALOG_MEASURE).build());
-                            if (g != null) {
-                                log.info("group {} created", g.getMetadata().getName());
-                            }
-                        }
-                    } catch (BanyanDBException ex) {
-                        if (ex.getStatus().equals(Status.Code.ALREADY_EXISTS)) {
-                            log.info("group {} already created by another OAP node", this.group);
-                        } else {
-                            throw ex;
-                        }
-                    }
-                    return resourceExist.hasResource();
-                default:
-                    throw new IllegalStateException("should not reach here");
-            }
-        }
-
         /**
          * @return name of the Stream/Measure in the BanyanDB
          */
@@ -701,7 +618,7 @@ public enum MetadataRegistry {
     }
 
     public enum Kind {
-        MEASURE, STREAM;
+        MEASURE, STREAM, PROPERTY;
     }
 
     @RequiredArgsConstructor
@@ -737,52 +654,17 @@ public enum MetadataRegistry {
 
         @Getter
         @Nullable
-        private final TopNSpec topNSpec;
+        private final TopNAggregation topNSpec;
 
         public ColumnSpec getSpec(String columnName) {
             return this.specs.get(columnName);
         }
 
-        public void installTopNAggregation(BanyanDBClient client) throws BanyanDBException {
-            if (this.getTopNSpec() == null) {
-                if (this.metadata.kind == Kind.MEASURE) {
-                    log.debug("skip null TopN Schema for [{}]", metadata.getModelName());
-                }
-                return;
-            }
-            TopNAggregation.Builder builder
-                = TopNAggregation.newBuilder()
-                                 .setMetadata(Metadata.newBuilder()
-                                                      .setGroup(getMetadata().getGroup())
-                                                      .setName(this.getTopNSpec().getName()))
-
-                                 .setSourceMeasure(Metadata.newBuilder()
-                                                           .setGroup(getMetadata().getGroup())
-                                                           .setName(getMetadata().name()))
-                                 .setFieldValueSort(this.getTopNSpec().getSort())
-                                 .setFieldName(this.getTopNSpec().getFieldName())
-                                 .addAllGroupByTagNames(this.getTopNSpec().getGroupByTagNames())
-                                 .setCountersNumber(this.getTopNSpec().getCountersNumber())
-                                 .setLruSize(this.getTopNSpec().getLruSize());
-            client.define(builder.build());
-            log.info("installed TopN schema for measure {}", getMetadata().name());
+        public static String formatTopNName(String measureName) {
+            return measureName + "_topn";
         }
     }
 
-    @Builder
-    @EqualsAndHashCode
-    @Getter
-    @ToString
-    public static class TopNSpec {
-        private final String name;
-        @Singular
-        private final List<String> groupByTagNames;
-        private final String fieldName;
-        private final BanyandbModel.Sort sort;
-        private final int lruSize;
-        private final int countersNumber;
-    }
-
     @RequiredArgsConstructor
     @Getter
     @ToString
@@ -794,11 +676,4 @@ public enum MetadataRegistry {
     public enum ColumnType {
         TAG, FIELD;
     }
-
-    @Getter
-    @Setter
-    @NoArgsConstructor
-    public static class GroupSetting {
-        private int segmentIntervalDays;
-    }
 }
