@@ -21,10 +21,17 @@ package org.apache.skywalking.oap.server.storage.plugin.banyandb.measure;
 import lombok.Getter;
 import lombok.RequiredArgsConstructor;
 import org.apache.skywalking.banyandb.v1.client.MeasureWrite;
+import org.apache.skywalking.oap.server.core.storage.SessionCacheCallback;
 import org.apache.skywalking.oap.server.library.client.request.InsertRequest;
 
 @RequiredArgsConstructor
 @Getter
 public class BanyanDBMeasureInsertRequest implements InsertRequest {
     private final MeasureWrite measureWrite;
+    private final SessionCacheCallback callback;
+
+    @Override
+    public void onInsertCompleted() {
+        callback.onInsertCompleted();
+    }
 }
\ No newline at end of file
