@@ -19,14 +19,12 @@
 package org.apache.skywalking.oap.server.storage.plugin.banyandb.measure;
 
 import com.google.common.collect.ImmutableSet;
-
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-
 import lombok.extern.slf4j.Slf4j;
 import org.apache.skywalking.banyandb.v1.client.DataPoint;
 import org.apache.skywalking.banyandb.v1.client.MeasureQuery;
@@ -39,12 +37,11 @@ import org.apache.skywalking.oap.server.core.analysis.metrics.Metrics;
 import org.apache.skywalking.oap.server.core.query.PointOfTime;
 import org.apache.skywalking.oap.server.core.query.input.Duration;
 import org.apache.skywalking.oap.server.core.query.input.MetricsCondition;
-import org.apache.skywalking.oap.server.core.query.sql.Function;
 import org.apache.skywalking.oap.server.core.query.type.HeatMap;
 import org.apache.skywalking.oap.server.core.query.type.IntValues;
 import org.apache.skywalking.oap.server.core.query.type.KVInt;
+import org.apache.skywalking.oap.server.core.query.type.KeyValue;
 import org.apache.skywalking.oap.server.core.query.type.MetricsValues;
-import org.apache.skywalking.oap.server.core.query.type.NullableValue;
 import org.apache.skywalking.oap.server.core.storage.annotation.ValueColumnMetadata;
 import org.apache.skywalking.oap.server.core.storage.query.IMetricsQueryDAO;
 import org.apache.skywalking.oap.server.storage.plugin.banyandb.BanyanDBStorageClient;
@@ -52,60 +49,14 @@ import org.apache.skywalking.oap.server.storage.plugin.banyandb.MetadataRegistry
 import org.apache.skywalking.oap.server.storage.plugin.banyandb.stream.AbstractBanyanDBDAO;
 import org.apache.skywalking.oap.server.storage.plugin.banyandb.util.ByteUtil;
 
+import static java.util.Objects.nonNull;
+
 @Slf4j
 public class BanyanDBMetricsQueryDAO extends AbstractBanyanDBDAO implements IMetricsQueryDAO {
     public BanyanDBMetricsQueryDAO(BanyanDBStorageClient client) {
         super(client);
     }
 
-    @Override
-    public NullableValue readMetricsValue(MetricsCondition condition, String valueColumnName, Duration duration) throws IOException {
-        String modelName = condition.getName();
-        MetadataRegistry.Schema schema = MetadataRegistry.INSTANCE.findMetadata(modelName, duration.getStep());
-        if (schema == null) {
-            throw new IOException("schema is not registered");
-        }
-
-        int defaultValue = ValueColumnMetadata.INSTANCE.getDefaultValue(condition.getName());
-        Function function = ValueColumnMetadata.INSTANCE.getValueFunction(condition.getName());
-        if (function == Function.Latest) {
-            return readMetricsValues(condition, valueColumnName, duration)
-                    .getValues().latestValue(defaultValue);
-        }
-
-        TimestampRange timestampRange = new TimestampRange(duration.getStartTimestamp(), duration.getEndTimestamp());
-        final MeasureQueryResponse resp = query(schema,
-                ImmutableSet.of(Metrics.ENTITY_ID),
-                ImmutableSet.of(valueColumnName),
-                timestampRange,
-                new QueryBuilder<MeasureQuery>() {
-                    @Override
-                    protected void apply(MeasureQuery query) {
-                        buildAggregationQuery(query, valueColumnName, function);
-                        if (condition.getEntity().buildId() != null) {
-                            query.and(eq(Metrics.ENTITY_ID, condition.getEntity().buildId()));
-                        }
-                    }
-                });
-
-        for (DataPoint dataPoint : resp.getDataPoints()) {
-            return new NullableValue(((Number) dataPoint.getFieldValue(valueColumnName)).longValue(), false);
-        }
-        return new NullableValue(defaultValue, true);
-    }
-
-    private void buildAggregationQuery(MeasureQuery query, String valueColumnName, Function function) {
-        switch (function) {
-            case Sum:
-                query.sumBy(valueColumnName, Collections.singleton(Metrics.ENTITY_ID));
-                break;
-            case Avg:
-            default:
-                query.meanBy(valueColumnName, Collections.singleton(Metrics.ENTITY_ID));
-                break;
-        }
-    }
-
     @Override
     public MetricsValues readMetricsValues(MetricsCondition condition, String valueColumnName, Duration duration) throws IOException {
         String modelName = condition.getName();
@@ -152,7 +103,7 @@ public class BanyanDBMetricsQueryDAO extends AbstractBanyanDBDAO implements IMet
     }
 
     @Override
-    public List<MetricsValues> readLabeledMetricsValues(MetricsCondition condition, String valueColumnName, List<String> labels, Duration duration) throws IOException {
+    public List<MetricsValues> readLabeledMetricsValues(MetricsCondition condition, String valueColumnName, List<KeyValue> labels, Duration duration) throws IOException {
         Map<Long, DataPoint> idMap = queryByEntityID(condition, valueColumnName, duration);
 
         List<PointOfTime> tsPoints = duration.assembleDurationPoints();
@@ -172,12 +123,59 @@ public class BanyanDBMetricsQueryDAO extends AbstractBanyanDBDAO implements IMet
         }
 
         return Util.sortValues(
-                Util.composeLabelValue(condition, labels, ids, dataTableMap),
+                Util.composeLabelValue(condition.getName(), labels, ids, dataTableMap),
                 ids,
                 ValueColumnMetadata.INSTANCE.getDefaultValue(condition.getName())
         );
     }
 
+    public List<MetricsValues> readLabeledMetricsValuesWithoutEntity(final String metricsName,
+                                                    final String valueColumnName,
+                                                    final List<KeyValue> labels,
+                                                    final Duration duration) throws IOException {
+        long startTB = 0;
+        long endTB = 0;
+        if (nonNull(duration)) {
+            startTB = duration.getStartTimeBucketInSec();
+            endTB = duration.getEndTimeBucketInSec();
+        }
+        TimestampRange timestampRange = null;
+        if (startTB > 0 && endTB > 0) {
+            timestampRange = new TimestampRange(TimeBucket.getTimestamp(startTB), TimeBucket.getTimestamp(endTB));
+        }
+        MetadataRegistry.Schema schema = MetadataRegistry.INSTANCE.findMetadata(metricsName, duration.getStep());
+        if (schema == null) {
+            throw new IOException("schema is not registered");
+        }
+        MeasureQueryResponse resp = query(
+            schema, ImmutableSet.of(Metrics.ENTITY_ID), ImmutableSet.of(valueColumnName), timestampRange,
+            new QueryBuilder<MeasureQuery>() {
+                @Override
+                protected void apply(MeasureQuery query) {
+                    query.limit(METRICS_VALUES_WITHOUT_ENTITY_LIMIT);
+                }
+            }
+        );
+        if (resp.size() == 0) {
+            return Collections.emptyList();
+        }
+        List<String> ids = new ArrayList<>(resp.size());
+        Map<String, DataTable> dataTableMap = new HashMap<>();
+        for (final DataPoint dp : resp.getDataPoints()) {
+            long timeBucket = TimeBucket.getTimeBucket(dp.getTimestamp(), schema.getMetadata().getDownSampling());
+            String entityID = dp.getTagValue(Metrics.ENTITY_ID);
+            PointOfTime pt = new PointOfTime(timeBucket);
+            String id = pt.id(entityID);
+            ids.add(id);
+            dataTableMap.put(id, new DataTable(dp.getFieldValue(valueColumnName)));
+        }
+        return Util.sortValues(
+            Util.composeLabelValue(metricsName, labels, ids, dataTableMap),
+            ids,
+            ValueColumnMetadata.INSTANCE.getDefaultValue(metricsName)
+        );
+    }
+
     @Override
     public HeatMap readHeatMap(MetricsCondition condition, String valueColumnName, Duration duration) throws IOException {
         Map<Long, DataPoint> idMap = queryByEntityID(condition, valueColumnName, duration);
@@ -219,7 +217,7 @@ public class BanyanDBMetricsQueryDAO extends AbstractBanyanDBDAO implements IMet
         TimestampRange timestampRange = new TimestampRange(duration.getStartTimestamp(), duration.getEndTimestamp());
 
         Map<Long, DataPoint> map = new HashMap<>();
-        MeasureQueryResponse resp = query(schema, ImmutableSet.of(Metrics.ENTITY_ID), ImmutableSet.of(valueColumnName), timestampRange, new QueryBuilder<MeasureQuery>() {
+        MeasureQueryResponse resp = queryDebuggable(schema, ImmutableSet.of(Metrics.ENTITY_ID), ImmutableSet.of(valueColumnName), timestampRange, new QueryBuilder<MeasureQuery>() {
             @Override
             protected void apply(MeasureQuery query) {
                 query.and(eq(Metrics.ENTITY_ID, entityID));
@@ -227,8 +225,9 @@ public class BanyanDBMetricsQueryDAO extends AbstractBanyanDBDAO implements IMet
         });
         for (final DataPoint dp : resp.getDataPoints()) {
             long timeBucket = TimeBucket.getTimeBucket(dp.getTimestamp(), schema.getMetadata().getDownSampling());
-            if (map.putIfAbsent(timeBucket, dp) != null) {
-                log.warn("duplicated data point at " + timeBucket);
+            DataPoint preDp = map.putIfAbsent(timeBucket, dp);
+            if (preDp != null) {
+                log.warn("{}:{} returns duplicated data point at {}, pre:{}, current:{}", entityID, schema.getMetadata(), timeBucket, preDp.getFields(), dp.getFields());
             }
         }
 
