@@ -40,9 +40,11 @@ public class BanyanDBEBPFProfilingDataDAO extends AbstractBanyanDBDAO implements
             EBPFProfilingDataRecord.TARGET_TYPE,
             EBPFProfilingDataRecord.DATA_BINARY,
             EBPFProfilingDataRecord.TASK_ID);
+    private final int profileDataQueryBatchSize;
 
-    public BanyanDBEBPFProfilingDataDAO(BanyanDBStorageClient client) {
+    public BanyanDBEBPFProfilingDataDAO(BanyanDBStorageClient client, int profileDataQueryBatchSize) {
         super(client);
+        this.profileDataQueryBatchSize = profileDataQueryBatchSize;
     }
 
     @Override
@@ -57,6 +59,7 @@ public class BanyanDBEBPFProfilingDataDAO extends AbstractBanyanDBDAO implements
                             query.and(eq(EBPFProfilingDataRecord.SCHEDULE_ID, scheduleId));
                             query.and(gte(EBPFProfilingDataRecord.UPLOAD_TIME, beginTime));
                             query.and(lte(EBPFProfilingDataRecord.UPLOAD_TIME, endTime));
+                            query.setLimit(profileDataQueryBatchSize);
                         }
                     }
             );
