@@ -36,15 +36,18 @@ public class BatchProcessEsDAO extends EsDAO implements IBatchDAO {
     private final int bulkActions;
     private final int flushInterval;
     private final int concurrentRequests;
+    private final int batchOfBytes;
 
     public BatchProcessEsDAO(ElasticSearchClient client,
                              int bulkActions,
                              int flushInterval,
-                             int concurrentRequests) {
+                             int concurrentRequests,
+                             int batchOfBytes) {
         super(client);
         this.bulkActions = bulkActions;
         this.flushInterval = flushInterval;
         this.concurrentRequests = concurrentRequests;
+        this.batchOfBytes = batchOfBytes;
     }
 
     @Override
@@ -53,7 +56,7 @@ public class BatchProcessEsDAO extends EsDAO implements IBatchDAO {
             synchronized (this) {
                 if (bulkProcessor == null) {
                     this.bulkProcessor = getClient().createBulkProcessor(
-                        bulkActions, flushInterval, concurrentRequests);
+                        bulkActions, flushInterval, concurrentRequests, batchOfBytes);
                 }
             }
         }
@@ -67,7 +70,7 @@ public class BatchProcessEsDAO extends EsDAO implements IBatchDAO {
             synchronized (this) {
                 if (bulkProcessor == null) {
                     this.bulkProcessor = getClient().createBulkProcessor(
-                        bulkActions, flushInterval, concurrentRequests);
+                        bulkActions, flushInterval, concurrentRequests, batchOfBytes);
                 }
             }
         }
