@@ -18,13 +18,14 @@
 
 package org.apache.skywalking.oap.server.storage.plugin.elasticsearch.base;
 
+import org.apache.skywalking.library.elasticsearch.response.Mappings;
+import org.apache.skywalking.oap.server.library.client.elasticsearch.ElasticSearchClient;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
+
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
-import org.apache.skywalking.library.elasticsearch.response.Mappings;
-import org.apache.skywalking.oap.server.library.client.elasticsearch.ElasticSearchClient;
-import org.junit.Assert;
-import org.junit.Test;
 
 public class IndexStructuresTest {
 
@@ -40,7 +41,7 @@ public class IndexStructuresTest {
                             .properties(properties)
                             .build(), new HashMap<>());
         Mappings mapping = structures.getMapping("test");
-        Assert.assertEquals(mapping.getProperties(), properties);
+        Assertions.assertEquals(mapping.getProperties(), properties);
 
         structures.putStructure(
             "test2", Mappings.builder()
@@ -49,7 +50,7 @@ public class IndexStructuresTest {
                              .build(), new HashMap<>());
         mapping = structures.getMapping("test2");
 
-        Assert.assertTrue(mapping.getProperties().isEmpty());
+        Assertions.assertTrue(mapping.getProperties().isEmpty());
         //test with source
         IndexStructures structuresSource = new IndexStructures();
         Mappings.Source source = new Mappings.Source();
@@ -60,8 +61,8 @@ public class IndexStructuresTest {
                             .properties(properties)
                             .source(source)
                             .build(), new HashMap<>());
-        Assert.assertEquals(properties, structuresSource.getMapping("test").getProperties());
-        Assert.assertEquals(source.getExcludes(), structuresSource.getMapping("test").getSource().getExcludes());
+        Assertions.assertEquals(properties, structuresSource.getMapping("test").getProperties());
+        Assertions.assertEquals(source.getExcludes(), structuresSource.getMapping("test").getSource().getExcludes());
     }
 
     @Test
@@ -77,7 +78,7 @@ public class IndexStructuresTest {
                             .source(new Mappings.Source())
                             .build(), new HashMap<>());
         Mappings mapping = structures.getMapping("test");
-        Assert.assertEquals(properties, mapping.getProperties());
+        Assertions.assertEquals(properties, mapping.getProperties());
         HashMap<String, Object> properties2 = new HashMap<>();
         properties2.put("a", "b");
         properties2.put("f", "g");
@@ -92,7 +93,7 @@ public class IndexStructuresTest {
         res.put("a", "b");
         res.put("c", "d");
         res.put("f", "g");
-        Assert.assertEquals(res, mapping.getProperties());
+        Assertions.assertEquals(res, mapping.getProperties());
 
         //test with source
         IndexStructures structuresSource = new IndexStructures();
@@ -104,8 +105,8 @@ public class IndexStructuresTest {
                             .properties(properties)
                             .source(source)
                             .build(), new HashMap<>());
-        Assert.assertEquals(properties, structuresSource.getMapping("test").getProperties());
-        Assert.assertEquals(source.getExcludes(), structuresSource.getMapping("test").getSource().getExcludes());
+        Assertions.assertEquals(properties, structuresSource.getMapping("test").getProperties());
+        Assertions.assertEquals(source.getExcludes(), structuresSource.getMapping("test").getSource().getExcludes());
 
         Mappings.Source source2 = new Mappings.Source();
         source.getExcludes().addAll(Arrays.asList("b", "c", "d", "e"));
@@ -115,8 +116,8 @@ public class IndexStructuresTest {
                             .properties(properties2)
                             .source(source)
                             .build(), new HashMap<>());
-        Assert.assertEquals(res, structuresSource.getMapping("test").getProperties());
-        Assert.assertEquals(new HashSet<>(Arrays.asList("a", "b", "c", "d", "e")), structuresSource.getMapping("test").getSource().getExcludes());
+        Assertions.assertEquals(res, structuresSource.getMapping("test").getProperties());
+        Assertions.assertEquals(new HashSet<>(Arrays.asList("a", "b", "c", "d", "e")), structuresSource.getMapping("test").getSource().getExcludes());
     }
 
     @Test
@@ -141,7 +142,7 @@ public class IndexStructuresTest {
         HashMap<String, Object> res = new HashMap<>();
         res.put("c", "d");
         res.put("f", "g");
-        Assert.assertEquals(res, diffMappings.getProperties());
+        Assertions.assertEquals(res, diffMappings.getProperties());
         diffMappings = structures.diffMappings(
             "test",
             Mappings.builder()
@@ -149,7 +150,7 @@ public class IndexStructuresTest {
                     .properties(properties)
                     .build()
         );
-        Assert.assertEquals(new HashMap<>(), diffMappings.getProperties());
+        Assertions.assertEquals(new HashMap<>(), diffMappings.getProperties());
 
         //test with source
         IndexStructures structuresSource = new IndexStructures();
@@ -167,15 +168,15 @@ public class IndexStructuresTest {
                             .properties(properties2)
                             .source(source)
                             .build());
-        Assert.assertEquals(res, diffMappings.getProperties());
+        Assertions.assertEquals(res, diffMappings.getProperties());
         diffMappings = structuresSource.diffMappings(
             "test", Mappings.builder()
                             .type(ElasticSearchClient.TYPE)
                             .properties(properties2)
                             .source(source)
                             .build());
-        Assert.assertEquals(res, diffMappings.getProperties());
-        Assert.assertNull("Mapping source should not be return by diffStructure()", diffMappings.getSource());
+        Assertions.assertEquals(res, diffMappings.getProperties());
+        Assertions.assertNull(diffMappings.getSource(), "Mapping source should not be return by diffStructure()");
         diffMappings = structuresSource.diffMappings(
             "test",
             Mappings.builder()
@@ -184,7 +185,7 @@ public class IndexStructuresTest {
                     .source(source)
                     .build()
         );
-        Assert.assertEquals(new HashMap<>(), diffMappings.getProperties());
+        Assertions.assertEquals(new HashMap<>(), diffMappings.getProperties());
     }
 
     @Test
@@ -203,7 +204,7 @@ public class IndexStructuresTest {
         HashMap<String, Object> properties2 = new HashMap<>();
         properties2.put("a", "b");
         properties2.put("c", "d");
-        Assert.assertTrue(structures.containsMapping(
+        Assertions.assertTrue(structures.containsMapping(
             "test",
             Mappings.builder()
                     .type(ElasticSearchClient.TYPE)
@@ -215,7 +216,7 @@ public class IndexStructuresTest {
         HashMap<String, Object> properties3 = new HashMap<>();
         properties3.put("a", "b");
         properties3.put("q", "d");
-        Assert.assertFalse(structures.containsMapping(
+        Assertions.assertFalse(structures.containsMapping(
             "test",
             Mappings.builder()
                     .type(ElasticSearchClient.TYPE)
@@ -239,7 +240,7 @@ public class IndexStructuresTest {
         settings2.put("index", indexSettings2);
         indexSettings2.put("number_of_replicas", "1");
         indexSettings2.put("number_of_shards", "1");
-        Assert.assertTrue(structures.compareIndexSetting(
+        Assertions.assertTrue(structures.compareIndexSetting(
             "test",
             settings2
         ));
@@ -249,7 +250,7 @@ public class IndexStructuresTest {
         settings3.put("index", indexSettings3);
         indexSettings3.put("number_of_replicas", "1");
         indexSettings3.put("number_of_shards", "2");
-        Assert.assertFalse(structures.compareIndexSetting(
+        Assertions.assertFalse(structures.compareIndexSetting(
             "test",
             settings3
         ));
