@@ -24,11 +24,12 @@ import org.apache.skywalking.oap.server.core.analysis.metrics.Metrics;
 import org.apache.skywalking.oap.server.core.analysis.record.Record;
 import org.apache.skywalking.oap.server.core.query.enumeration.Step;
 import org.apache.skywalking.oap.server.core.storage.model.BanyanDBModelExtension;
+import org.apache.skywalking.oap.server.core.storage.model.ElasticSearchModelExtension;
 import org.apache.skywalking.oap.server.core.storage.model.Model;
 import org.apache.skywalking.oap.server.core.storage.model.SQLDatabaseModelExtension;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import static org.apache.skywalking.oap.server.storage.plugin.elasticsearch.base.TimeSeriesUtils.compressTimeBucket;
 import static org.apache.skywalking.oap.server.storage.plugin.elasticsearch.base.TimeSeriesUtils.writeIndexName;
@@ -39,19 +40,19 @@ public class TimeSeriesUtilsTest {
     private Model normalRecordModel;
     private Model normalMetricsModel;
 
-    @Before
+    @BeforeEach
     public void prepare() {
         superDatasetModel = new Model("superDatasetModel", Lists.newArrayList(),
-                                      0, DownSampling.Second, true, true, Record.class, true,
-                                      new SQLDatabaseModelExtension(), new BanyanDBModelExtension()
+                                      0, DownSampling.Second, true, Record.class, true,
+                                      new SQLDatabaseModelExtension(), new BanyanDBModelExtension(), new ElasticSearchModelExtension()
         );
         normalRecordModel = new Model("normalRecordModel", Lists.newArrayList(),
-                                      0, DownSampling.Second, true, false, Record.class, true,
-                                      new SQLDatabaseModelExtension(), new BanyanDBModelExtension()
+                                      0, DownSampling.Second, false, Record.class, true,
+                                      new SQLDatabaseModelExtension(), new BanyanDBModelExtension(), new ElasticSearchModelExtension()
         );
         normalMetricsModel = new Model("normalMetricsModel", Lists.newArrayList(),
-                                       0, DownSampling.Minute, false, false, Metrics.class, true,
-                                       new SQLDatabaseModelExtension(), new BanyanDBModelExtension()
+                                       0, DownSampling.Minute, false, Metrics.class, true,
+                                       new SQLDatabaseModelExtension(), new BanyanDBModelExtension(), new ElasticSearchModelExtension()
         );
         TimeSeriesUtils.setSUPER_DATASET_DAY_STEP(1);
         TimeSeriesUtils.setDAY_STEP(3);
@@ -59,12 +60,12 @@ public class TimeSeriesUtilsTest {
 
     @Test
     public void testCompressTimeBucket() {
-        Assert.assertEquals(20000101L, compressTimeBucket(20000105, 11));
-        Assert.assertEquals(20000101L, compressTimeBucket(20000111, 11));
-        Assert.assertEquals(20000112L, compressTimeBucket(20000112, 11));
-        Assert.assertEquals(20000112L, compressTimeBucket(20000122, 11));
-        Assert.assertEquals(20000123L, compressTimeBucket(20000123, 11));
-        Assert.assertEquals(20000123L, compressTimeBucket(20000125, 11));
+        Assertions.assertEquals(20000101L, compressTimeBucket(20000105, 11));
+        Assertions.assertEquals(20000101L, compressTimeBucket(20000111, 11));
+        Assertions.assertEquals(20000112L, compressTimeBucket(20000112, 11));
+        Assertions.assertEquals(20000112L, compressTimeBucket(20000122, 11));
+        Assertions.assertEquals(20000123L, compressTimeBucket(20000123, 11));
+        Assertions.assertEquals(20000123L, compressTimeBucket(20000125, 11));
     }
 
     @Test
@@ -72,29 +73,29 @@ public class TimeSeriesUtilsTest {
         long secondTimeBucket = 2020_0809_1010_59L;
         long minuteTimeBucket = 2020_0809_1010L;
 
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "superDatasetModel-20200809",
             writeIndexName(superDatasetModel, secondTimeBucket)
         );
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "records-all-20200807",
             writeIndexName(normalRecordModel, secondTimeBucket)
         );
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "metrics-all-20200807",
             writeIndexName(normalMetricsModel, minuteTimeBucket)
         );
         secondTimeBucket += 1000000;
         minuteTimeBucket += 10000;
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "superDatasetModel-20200810",
             writeIndexName(superDatasetModel, secondTimeBucket)
         );
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "records-all-20200810",
             writeIndexName(normalRecordModel, secondTimeBucket)
         );
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "metrics-all-20200810",
             writeIndexName(normalMetricsModel, minuteTimeBucket)
         );
@@ -102,23 +103,23 @@ public class TimeSeriesUtilsTest {
 
     @Test
     public void queryIndexNameTest() {
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "metrics-apdex-20220710",
             TimeSeriesUtils.queryIndexName("metrics-apdex", 20220710111111L, Step.SECOND, false, false)
         );
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "metrics-apdex-20220710",
             TimeSeriesUtils.queryIndexName("metrics-apdex", 202207101111L, Step.MINUTE, false, false)
         );
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "metrics-apdex-20220710",
             TimeSeriesUtils.queryIndexName("metrics-apdex", 2022071011L, Step.HOUR, false, false)
         );
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "metrics-apdex-20220710",
             TimeSeriesUtils.queryIndexName("metrics-apdex", 20220710L, Step.DAY, false, false)
         );
-        Assert.assertEquals(
+        Assertions.assertEquals(
             "metrics-apdex-20220710",
             TimeSeriesUtils.queryIndexName("metrics-apdex", 20220710111111L, Step.DAY, true, true)
         );
