@@ -17,7 +17,7 @@
 class Vec3 extends Float32Array {
   constructor(v?: unknown, y?: unknown, z?: unknown) {
     super(3);
-    if (v instanceof Vec3 || v instanceof Float32Array || (v instanceof Array && v.length == 3)) {
+    if (v instanceof Vec3 || v instanceof Float32Array || (v instanceof Array && v.length === 3)) {
       this[0] = v[0];
       this[1] = v[1];
       this[2] = v[2];
@@ -150,7 +150,7 @@ class Vec3 extends Float32Array {
   }
   static norm(x: unknown, y: unknown, z: unknown): Vec3 {
     const rtn = new Vec3();
-    if (x instanceof Vec3 || x instanceof Float32Array || (x instanceof Array && x.length == 3)) {
+    if (x instanceof Vec3 || x instanceof Float32Array || (x instanceof Array && x.length === 3)) {
       rtn.copy(x);
     } else if (typeof x === "number" && typeof y === "number" && typeof z === "number") {
       rtn.xyz(x, y, z);
