@@ -74,8 +74,8 @@ export const BrowserLogConstants = [
     value: "serviceVersion",
   },
   {
-    label: "errorUrl",
-    value: "errorPage",
+    label: "pagePath",
+    value: "pagePath",
   },
   {
     label: "time",
@@ -87,6 +87,10 @@ export const BrowserLogConstants = [
     // drag: true,
     method: 350,
   },
+  {
+    label: "errorUrl",
+    value: "errorUrl",
+  },
   {
     label: "stack",
     value: "stack",
